SigHandler

Enum SigHandler 

pub enum SigHandler {
    SigDfl,
    SigIgn,
    Handler(extern "C" fn(c_int)),
    SigAction(extern "C" fn(c_int, *mut siginfo_t, *mut c_void)),
}
A signal handler.

Variants



SigDfl

Default signal handling.



SigIgn

Request that the signal be ignored.



Handler(extern "C" fn(c_int))

Use the given signal-catching function, which takes in the signal.



SigAction(extern "C" fn(c_int, *mut siginfo_t, *mut c_void))

Use the given signal-catching function, which takes in the signal, information about how the signal was generated, and a pointer to the threads ucontext_t.